@@ -3,16 +3,15 @@ from typing import Any, Dict, List, Optional
 from datetime import datetime
 
 from resinkit_api.clients.job_manager.flink_job_manager_client import FlinkJobManager
-from resinkit_api.clients.sql_gateway.flink_session import FlinkSession
 from resinkit_api.clients.sql_gateway.flink_sql_gateway_client import FlinkSqlGatewayClient, FlinkSqlGatewayNotFoundException
-from resinkit_api.clients.sql_gateway.flink_operation import FlinkOperation, ResultsFetchOpts
+from resinkit_api.clients.sql_gateway.flink_operation import ResultsFetchOpts
 from resinkit_api.core.logging import get_logger
 from resinkit_api.db.models import Task, TaskStatus
-from resinkit_api.services.agent.flink.flink_resource_manager import FlinkResourceManager
+from resinkit_api.services.agent.flink.flink_resource_manager import FlinkResourceManager, FlinkResourcesResult
 from resinkit_api.services.agent.flink.flink_sql_task import FlinkSQLTask
 from resinkit_api.services.agent.task_base import TaskBase
 from resinkit_api.services.agent.task_runner_base import TaskRunnerBase, LogEntry
-from resinkit_api.services.agent.data_models import TaskExecutionError, FlinkJobStatus, map_flink_status_to_task_status
+from resinkit_api.services.agent.data_models import FlinkJobStatus, map_flink_status_to_task_status
 from resinkit_api.services.agent.common.log_file_manager import LogFileManager
 import pandas as pd
 import json
@@ -97,7 +96,7 @@ class FlinkSQLRunner(TaskRunnerBase):
         self.tasks[task_id] = task
 
         # Process resources
-        resources = await self.resource_manager.process_resources(task.resources)
+        resources: FlinkResourcesResult = await self.resource_manager.process_resources(task.resources)
 
         lfm = LogFileManager(task.log_file, limit=1000, logger=logger)
 
@@ -292,7 +291,7 @@ class FlinkSQLRunner(TaskRunnerBase):
         except Exception as e:
             logger.error(f"Error cleaning up resources: {str(e)}")
 
-    def _create_session_properties(self, task: FlinkSQLTask, resources: Dict[str, List[str]]) -> Dict[str, str]:
+    def _create_session_properties(self, task: FlinkSQLTask, resources: FlinkResourcesResult) -> Dict[str, str]:
         """
         Create session properties for the Flink SQL Gateway.
 
@@ -306,13 +305,13 @@ class FlinkSQLRunner(TaskRunnerBase):
         properties = {}
 
         # Add jar paths
-        if resources.get("jar_paths"):
-            jar_paths = ";".join(resources["jar_paths"])
+        if resources.jar_paths:
+            jar_paths = ";".join(resources.jar_paths)
             properties["pipeline.jars"] = jar_paths
 
         # Add classpath jars
-        if resources.get("classpath_jars"):
-            classpath_jars = ";".join(resources["classpath_jars"])
+        if resources.classpath_jars:
+            classpath_jars = ";".join(resources.classpath_jars)
             properties["pipeline.classpaths"] = classpath_jars
 
         # Set parallelism
@@ -370,7 +369,7 @@ class FlinkSQLRunner(TaskRunnerBase):
 
         return task
 
-    async def _determine_task_status_from_flink_jobs(self, task: FlinkSQLTask, job_ids: List[str], lfm) -> FlinkSQLTask:
+    async def _determine_task_status_from_flink_jobs(self, task: FlinkSQLTask, job_ids: List[str], lfm: LogFileManager) -> FlinkSQLTask:
         """
         Determine task status based on Flink job statuses.
 
