@@ -437,18 +437,20 @@ class TaskTiqManager:
         if is_taskiq_ready:
             self._active_tasks.pop(db_task.task_id, None)
 
+        if db_task.result_summary.get("all_jobs_finished") is True:
+            return db_task
+
         runner = get_runner_for_task_type(db_task.task_type)
         dto_task = await runner.fetch_task_status(runner.from_dao(db_task))
-        if db_task.status != dto_task.status:
-            db_task = tasks_crud.update_task_status(
-                db=db,
-                task_id=db_task.task_id,
-                new_status=dto_task.status,
-                actor="taskiq",
-                error_info=dto_task.error_info,
-                result_summary=dto_task.result_summary,
-                execution_details=dto_task.execution_details,
-            )
+        db_task = tasks_crud.update_task_status(
+            db=db,
+            task_id=db_task.task_id,
+            new_status=dto_task.status,
+            actor="taskiq",
+            error_info=dto_task.error_info,
+            result_summary=dto_task.result_summary,
+            execution_details=dto_task.execution_details,
+        )
 
         if dto_task.status.is_terminal():
             self._active_tasks.pop(db_task.task_id, None)
